using System;
using System.Collections;
using System.Configuration;
using System.Data;
using System.Data.SqlClient;
using System.Web;
using System.Security.Cryptography;
using System.Text;
using System.Text.RegularExpressions;

namespace  Student
		 			  
{
	// Klasa StudentOchrona odpowiada za ochron aplikacji
	public class StudentOchrona
	{
		// Metoda Szyfr odpowiada za szyfrowanie danych w cookies
		public static string Szyfr(string cleanString)
		{
			Byte[] clearBytes = new UnicodeEncoding().GetBytes(cleanString);
			Byte[] hashedBytes = ((HashAlgorithm) CryptoConfig.CreateFromName("MD5")).ComputeHash(clearBytes);
			
			return BitConverter.ToString(hashedBytes);
		}

		// Metoda Funkcja sprawdza rol jak peni zalogowany uytkownik w systemie 
		public static bool Funkcja(String rola) 
		{

			return HttpContext.Current.User.IsInRole(rola);
		}

		// Sprawdzenie roli uytkownika w kontekscie wszystkich rl
		public static bool SprawdzenieFunkcji (String funkcje) 
		{

			HttpContext context = HttpContext.Current;

			foreach (String rola in funkcje.Split( new char[] {';'} )) 
			{
				if (rola != "" && funkcje != null && (context.User.IsInRole(rola))) 	
			{
					return true;
				}
			}

			return false;
		}

	}

		// Klasa Uzytkownik CTR odpowiedzialna jest za dodanie i wczytanie danych uytkownika
		public class UzytkownikCTR 
		{
			//Dodanie nowego uytkownika do bazy danych
			public int DodajUzytkownika(String fullNazwa, String login, String haslo) 
			{

				// Tworzenie egzemplarza poczenia i polecenia
				SqlConnection myConnection = new SqlConnection(ConfigurationSettings.AppSettings["parametryPolaczenia"]);
				SqlCommand myCommand = new SqlCommand("Dodaj_Uzytkownika", myConnection);

				// Ustawienie polecenia jako procedura wbudowana
				myCommand.CommandType = CommandType.StoredProcedure;

				// Dodawanie parametrw do procedury wbudowanej
				SqlParameter parameterFullNazwa = new SqlParameter("@Nazwa", SqlDbType.NVarChar, 50);
				parameterFullNazwa.Value = fullNazwa;
				myCommand.Parameters.Add(parameterFullNazwa);

				SqlParameter parameterLogin = new SqlParameter("@Login", SqlDbType.NVarChar, 100);
				parameterLogin.Value = login;
				myCommand.Parameters.Add(parameterLogin);

				SqlParameter parameterHaslo = new SqlParameter("@Haslo", SqlDbType.NVarChar, 50);
				parameterHaslo.Value = haslo;
				myCommand.Parameters.Add(parameterHaslo);

				SqlParameter parameterUzytkownikID = new SqlParameter("@UzytkownikID", SqlDbType.Int);
				parameterUzytkownikID.Direction = ParameterDirection.Output;
				myCommand.Parameters.Add(parameterUzytkownikID);

				// Wykonanie polecenia w try/catch w celu wychwycenia takiej samej nazwy uytkownika
				try 
				{
					// Otworzenie poaczenia z baz danych
					myConnection.Open();
					// Wykonywanie polecenia
					myCommand.ExecuteNonQuery();
				}
				catch 
				{

					// niepowodzeni w tworzeniu nowego uytkownika
					return -1;
				}
				finally 
				{

					// Zamkniecie poaczenia z serverem
					if (myConnection.State == ConnectionState.Open)
						myConnection.Close();
				}

				return (int) parameterUzytkownikID.Value;
			}

			// metoda Kasuj uytkownika odpowiada za skasowanie uytkownika za bazy danych
			public void KasujUzytkownika(int uzytkownikID) 
			{

				// Tworzenie egzemplarza poczenia i polecenia
				SqlConnection myConnection = new SqlConnection(ConfigurationSettings.AppSettings["parametryPolaczenia"]);
				SqlCommand myCommand = new SqlCommand("Kasuj_Uzytkownika", myConnection);

				// Ustawienie polecenia jako procedura wbudowana
				myCommand.CommandType = CommandType.StoredProcedure;

				SqlParameter parameterUzytkownikID = new SqlParameter("@UzytkownikID", SqlDbType.Int);
				parameterUzytkownikID.Value = uzytkownikID;
				myCommand.Parameters.Add(parameterUzytkownikID);

				// Otworzenie poczenia z baz danych i wykonanie polecenia a nastpnie jej zamknicie
				myConnection.Open();
				myCommand.ExecuteNonQuery();
				myConnection.Close();
			}

			// Metoda PoprawUzytkownika odpowiada za aktualizacj danych o uytkownikach
			public void PoprawUzytkownika(int uzytkownikID, String login, String haslo) 
			{

				// Tworzenie egzemplarza poczenia i polecenia
				SqlConnection myConnection = new SqlConnection(ConfigurationSettings.AppSettings["parametryPolaczenia"]);
				SqlCommand myCommand = new SqlCommand("Popraw_Uzytkownika", myConnection);

				// Ustawienie polecenia jako procedura wbudowana
				myCommand.CommandType = CommandType.StoredProcedure;

				SqlParameter parameterUzytkownikID = new SqlParameter("@UzytkownikID", SqlDbType.Int);
				parameterUzytkownikID.Value = uzytkownikID;
				myCommand.Parameters.Add(parameterUzytkownikID);

				SqlParameter parameterLogin = new SqlParameter("@Login", SqlDbType.NVarChar, 100);
				parameterLogin.Value = login;
				myCommand.Parameters.Add(parameterLogin);

				SqlParameter parameterHaslo = new SqlParameter("@Haslo", SqlDbType.NVarChar, 50);
				parameterHaslo.Value = haslo;
				myCommand.Parameters.Add(parameterHaslo);

				// Otworzenie poczenia z baz danych i wykonanie polecenia a nastpnie jej zamknicie
				myConnection.Open();
				myCommand.ExecuteNonQuery();
				myConnection.Close();
			}

			// Metoda WezRoleUzytkownikow odpowiada za popbranie odpowiednich rl przypisanych uytkownikom
			public SqlDataReader WezRoleUzytkownikow(String login) 
			{

				// Tworzenie egzemplarza poczenia i polecenia
				SqlConnection myConnection = new SqlConnection(ConfigurationSettings.AppSettings["parametryPolaczenia"]);
				SqlCommand myCommand = new SqlCommand("Wez_RoleUzytkownikow", myConnection);

				// Ustawienie polecenia jako procedura wbudowana
				myCommand.CommandType = CommandType.StoredProcedure;

				SqlParameter parameterLogin = new SqlParameter("@Login", SqlDbType.NVarChar, 100);
				parameterLogin.Value = login;
				myCommand.Parameters.Add(parameterLogin);

				// Otworzenie poczenia z baz danych i wykonanie polecenia a nastpnie jej zamknicie
				myConnection.Open();
				SqlDataReader dr = myCommand.ExecuteReader(CommandBehavior.CloseConnection);

				// Zwrcenie danych 
				return dr;
			}

			// Metoda WezPojUzytkownika zwraca dane o jednym uytkowniku
			public SqlDataReader WezPojUzytkownika(String login) 
			{

				// Tworzenie egzemplarza poczenia i polecenia
				SqlConnection myConnection = new SqlConnection(ConfigurationSettings.AppSettings["parametryPolaczenia"]);
				SqlCommand myCommand = new SqlCommand("Wez_PojUzytkownika", myConnection);

				// Ustawienie polecenia jako procedura wbudowana
				myCommand.CommandType = CommandType.StoredProcedure;

				// Dodawanie parametrw do procedury wbudowanej
				SqlParameter parameterLogin = new SqlParameter("@Login", SqlDbType.NVarChar, 100);
				parameterLogin.Value = login;
				myCommand.Parameters.Add(parameterLogin);

				// Otworzenie poczenia z baz danych i wykonanie polecenia a nastpnie jej zamknicie
				myConnection.Open();
				SqlDataReader dr = myCommand.ExecuteReader(CommandBehavior.CloseConnection);

				// Zwrcenie danych 
				return dr;
			}
			
			//Metoda Wez role zwraca liste rlo przypisanych uytkownikowi
			public String[] WezRole(String login) 
			{

				// Tworzenie egzemplarza poczenia i polecenia
				SqlConnection myConnection = new SqlConnection(ConfigurationSettings.AppSettings["parametryPolaczenia"]);
				SqlCommand myCommand = new SqlCommand("Wez_RoleUzytkownikow", myConnection);

				// Ustawienie polecenia jako procedura wbudowana
				myCommand.CommandType = CommandType.StoredProcedure;

				// Dodawanie parametrw do procedury wbudowanej
				SqlParameter parameterLogin = new SqlParameter("@Login", SqlDbType.NVarChar, 100);
				parameterLogin.Value = login;
				myCommand.Parameters.Add(parameterLogin);

				// Otworzenie poczenia z baz danych i wykonanie polecenia a nastpnie jej zamknicie
				SqlDataReader dr;

				myConnection.Open();
				dr = myCommand.ExecuteReader(CommandBehavior.CloseConnection);

				// Tworzenie zestawienia z  otrzymanych danych
				ArrayList funkcjeUzytkownikow = new ArrayList();

				while (dr.Read()) 
				{
					funkcjeUzytkownikow.Add(dr["NazwaFunkcji"]);
				}

				dr.Close();

				// Zwrcenie zestawienia rl
				return (String[]) funkcjeUzytkownikow.ToArray(typeof(String));
			}
			// Pobiera fukcje uytkownika
			public SqlDataReader WezFunkcje(String login) 
			{

				// Tworzenie egzemplarza poczenia i polecenia
				SqlConnection myConnection = new SqlConnection(ConfigurationSettings.AppSettings["parametryPolaczenia"]);
				SqlCommand myCommand = new SqlCommand("Wez_Funkcje", myConnection);

				// Ustawienie polecenia jako procedura wbudowana
				myCommand.CommandType = CommandType.StoredProcedure;

				// Dodawanie parametrw do procedury wbudowanej
				SqlParameter parameterLogin = new SqlParameter("@Login", SqlDbType.NVarChar, 100);
				parameterLogin.Value = login;
				myCommand.Parameters.Add(parameterLogin);

				// Wykonanie polecenia
				myConnection.Open();
				SqlDataReader result = myCommand.ExecuteReader(CommandBehavior.CloseConnection);
            
				// Zwrcenie danych  
				return result;
			}
			
			// Metoda Logowanie sprawdza par danych  login i haso w bazie danych 
			public String Logowanie(String login, String haslo) 
			{

				// Tworzenie egzemplarza poczenia i polecenia
				SqlConnection myConnection = new SqlConnection(ConfigurationSettings.AppSettings["parametryPolaczenia"]);
				SqlCommand myCommand = new SqlCommand("Logowanie_Uzytkownika", myConnection);

				// Ustawienie polecenia jako procedura wbudowana
				myCommand.CommandType = CommandType.StoredProcedure;

				// Dodawanie parametrw do procedury wbudowanej
				SqlParameter parameterLogin = new SqlParameter("@Login", SqlDbType.NVarChar, 100);
				parameterLogin.Value = login;
				myCommand.Parameters.Add(parameterLogin);

				SqlParameter parameterHaslo = new SqlParameter("@Haslo", SqlDbType.NVarChar, 50);
				parameterHaslo.Value = haslo;
				myCommand.Parameters.Add(parameterHaslo);

				SqlParameter parameterNazwa = new SqlParameter("@Nazwa", SqlDbType.NVarChar, 100);
				parameterNazwa.Direction = ParameterDirection.Output;
				myCommand.Parameters.Add(parameterNazwa);

				// Otworzenie poczenia z baz danych i wykonanie polecenia a nastpnie jej zamknicie
				myConnection.Open();
				myCommand.ExecuteNonQuery();
				myConnection.Close();

				if ((parameterNazwa.Value != null) && (parameterNazwa.Value != System.DBNull.Value)) 
				{
					return ((String)parameterNazwa.Value).Trim();
				}
				else 
				{
					return String.Empty;
				}
			}
		}
	
	}   

